#--> +++++++++++++++++++++++++++++++++++++++++++++++++++++++ <--#
#-->                                                         <--#
#-->                                                         <--#
#--> D. Appelbe Daresbury NPG 06/30/03                       <--#
#-->  V Pucknell  2005
#-->                                                         <--#
#--> +++++++++++++++++++++++++++++++++++++++++++++++++++++++ <--#

#--> +++++++++++++++++++++++++++++++++++++++++++++++++++++++ <--#
#--> Splash screen so the user knows what is going on ...    <--#
#--> +++++++++++++++++++++++++++++++++++++++++++++++++++++++ <--#

proc splash_create { image product copyright msg } {
    global tcl_version tk_version tcl_platform
    global tcl_patchLevel

    #--> If a splash screen exists we shall remove it 
    splash_remove
    toplevel .splash
    wm withdraw .splash
    #--> Center on screen
    splash_dialog_position .splash
    #--> Top area contains info
    set frm .splash.top
    frame $frm -bd 2 -relief groove
    #--> The image we shall display
    label $frm.logo -image $image
    #--> Label for product version number
    label $frm.product -text "$product"
    #--> message widget
    message $frm.copyright -text "$copyright" -width 3i
    #--> Label for OS version
    label $frm.osversion -text "$tcl_platform(os) $tcl_platform(osVersion)"
    #--> Layout
    pack $frm.logo -side top -fill x -pady 4 -ipadx 4 -ipady 4
    pack $frm.product $frm.copyright $frm.osversion -side top -fill x
    pack $frm -side top -fill x -padx 8 -pady 8
    #--> Bottom area contains the current message
    set frm .splash.bottom
    frame $frm -bd 2 -relief groove
    label $frm.msg -text "$msg" -anchor w
    pack $frm.msg -side left -ipadx 6 -ipady 4
    pack $frm -side bottom -fill x -padx 8 -pady 8
    wm deiconify .splash
    update
}

proc splash_update { msg } {
    set name .splash.bottom.msg

    if { [ winfo exists $name ] } then {
    $name config -text "$msg"
    update
    }
}

proc splash_remove { } {
    if { [ winfo exists .splash ] } then {
    destroy .splash
    }
}

proc splash_dialog_position { dlg } {
    set width  [ winfo screenwidth . ]
    set height [ winfo screenheight . ]

    set x [ expr ($width / 2 )  - 260 ]
    set y [ expr ($height / 2 ) - 260 ]

    wm geometry $dlg +$x+$y

}

proc set_colour {} {
    global mydebug
    
    if { $mydebug == 1 } then { puts "set_colour : Entered" }

    :colour local text background white
    :colour local text foreground blue

    if { $mydebug == 1 } then { puts "set_colour : Leaving" }
}


#--> +++++++++++++++++++++++++++++++++++++++++++++++++++++++ <--#
#--> Check to see if we have a valid EXPERIMENTDIR set       <--#
#--> +++++++++++++++++++++++++++++++++++++++++++++++++++++++ <--#

proc check_experiment {} {
    #--> before we look for any resources we have to ensure
    #--> that we are connected to a valid experiment
    global env mydebug userexpt

    if { $mydebug == 1 } then { puts "check_experiment: Entered" }
    if { $mydebug == 1 } then { array names env EXPERIMENTBASE }

    if {![info exists env(EXPERIMENTBASE)]} then {
    if { $mydebug == 1 } then { puts "check_experiment: NO Valid Expt" }
    #--> First we have to check are we big or little endian. It should not matter
    #--> for us as we are creating something on the fly, else .....
    if { $env(EXPUSEENDIAN) == "true" } then {
        set endian $env(ENDIAN)
    } else {
        set endian "big"
    }
    if { $mydebug == 1 } then { puts "check_experiment: endian     -> $endian " }
    set filename "capabilities"
    if { $mydebug == 1 } then { puts "check_experiment: filename   -> $filename" }
    #--> The name for this experiment is ....
    set experiment "midassort"
    if { $mydebug == 1 } then { puts "check_experiment: experiment -> $experiment" }
    set directory [file join $env(MIDASTempDir) tcl[pid]]
    set z [ catch { :file mkdir [ file join $directory $experiment ] } m ]
    if { $z != 0 } then {
        splash_update "Setting Experiment FAILED"
        return
    }
    if { $endian != "big" } then {
        set z [ catch { :file mkdir [ file join $directory $experiment $endian] } m ]
        if { $z != 0 } then {
        splash_update "Setting Experiment FAILED"
        return
        }
    }
    if { $mydebug == 1 } then { puts "check_experiment: Directory created" }
    #--> now set the Experiment directory
    global EGallow; set EGallow 0x10008; :experiment disconnect; set EGallow -1
    if { $endian == "big" } then {
        :experiment delete :path [ file join $directory $experiment ] :name $filename
        :experiment new :path [ file join $directory $experiment ] :name $filename
        if { $mydebug == 1 } then { puts "check_experiment: Temporary experiment has been created" }
        splash_update "Temporary experiment has been created ..."
    } else {
        :experiment delete :path [ file join $directory $experiment $endian] :name $filename
        :experiment new :path [ file join $directory $experiment $endian] :name $filename
        if { $mydebug == 1 } then { puts "check_experiment: Temporary experiment has been created" }
        splash_update "Temporary experiment has been created ..."
    }

    if { $endian == "big" } then {
        :experiment connect :path [ file join $directory $experiment ] :name $filename
        set env(EXPERIMENTDIR) [ file join $directory $experiment ]
        if { $mydebug == 1 } then { puts "check_experiment: Temporary experiment has been joined" }
    } else {
        :experiment connect :path [ file join $directory $experiment $endian ] :name $filename
        set env(EXPERIMENTDIR) [ file join $directory $experiment $endian ]
        if { $mydebug == 1 } then { puts "check_experiment: Temporary experiment has been joined" }
    }
    set env(EXPERIMENTBASE) [file join $directory $experiment]
      
    after 1000
    splash_update "Temporary experiment has been Joined ... "
    after 1000
    splash_update "Informing MIDAS-Session about new experiment .."
    #--> Send a message to the logger so that we know where we are "
    insert-log "MIDASsort-> Created & Joined temporary experiment"
    #--> Now tell the rest of the session what we have done ...
    foreach task [ Get_Task_Names ] {
        if {[inform $task "info procs set-experiment"] == "set-experiment"} then {
        if { $mydebug == 1 } then { puts "check_experiment : informing $task set-experiment" }
        inform $task set-experiment [file join $directory $experiment]
        }
    }

    set userexpt 1
    } else {
    if { $mydebug == 1 } then { puts "check_experiment: Valid Expt" }
    splash_update "Valid Experiment set ..."
    after 1000
    }
    
}
